searchData={"items":[{"type":"module","title":"Carrier","doc":"Elixir library for interacting with Smarty's API. The main functions in this\nmodule are `verify/1` to verify a single address and `verify_many/1` to verify\nmultiple addresses using batch processing.","ref":"Carrier.html"},{"type":"function","title":"Carrier.standardize_request/1","doc":"This is the function used to standardize requests. You should not need to use\nthis function directly, as it is called by `verify/1` and `verify_many/1`. It\nis public for testing purposes.","ref":"Carrier.html#standardize_request/1"},{"type":"function","title":"Carrier.standardize_result/1","doc":"This is the function used to standardize responses. You should not need to use\nthis function directly, as it is called by `verify/1` and `verify_many/1`. It\nis public for testing purposes.","ref":"Carrier.html#standardize_result/1"},{"type":"function","title":"Carrier.verify/1","doc":"Verifies a single address.","ref":"Carrier.html#verify/1"},{"type":"function","title":"Carrier.verify_many/1","doc":"Verifies multiple addresses in a batch.","ref":"Carrier.html#verify_many/1"},{"type":"extras","title":"Carrier","doc":"# Carrier\n\n![Elixir CI](https://github.com/mylanconnolly/carrier/workflows/Elixir%20CI/badge.svg)\n\nThis is an unofficial Elixir client for the excellent\n[Smarty](https://smarty.com/) address verification service.\n\nIt's fairly bare-bones because all we need it for is verifying and standardizing\naddresses, however it might get beefed up in the future. There's a ton of data\nprovided by Smarty in addition to the verification process, and some of\nit might be pretty useful to have (such as geo-coding, timezone data, etc.).\n\nIt is essentially just a `GenServer` that handles the minutiae of communicating\nwith the Smarty API.","ref":"readme.html"},{"type":"extras","title":"Installation - Carrier","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"Add carrier to your list of dependencies in `mix.exs`: - Carrier","doc":"```elixir\ndef deps do\n  [{:carrier, \"~> 2.0\"}]\nend\n```","ref":"readme.html#add-carrier-to-your-list-of-dependencies-in-mix-exs"},{"type":"extras","title":"Configuration - Carrier","doc":"Carrier supports environment-specific configuration for working with the Smarty API. You can configure it in different ways depending on your environment:\n\n#### Production\n\nIn production, use environment variables for sensitive data:\n\n```elixir\n# config/prod.exs\nconfig :carrier, Carrier,\n  auth_id: System.get_env(\"SMARTY_AUTH_ID\"),\n  auth_token: System.get_env(\"SMARTY_AUTH_TOKEN\")\n```\n\n#### Development\n\nFor local development, you can either:\n\n1. Set environment variables:\n\n   ```bash\n   export SMARTY_AUTH_ID=your_auth_id_here\n   export SMARTY_AUTH_TOKEN=your_auth_token_here\n   ```\n\n2. Or create a `.env` file based on the provided `.env.example` and use a library like [Dotenv](https://github.com/avdi/dotenv_elixir) to load it.\n\n#### Testing and CI\n\nFor testing and CI environments, you can:\n\n1. Set environment variables in your CI platform\n2. Use the default test values provided in `config/test.exs`\n\n```elixir\n# config/test.exs\nconfig :carrier, Carrier,\n  auth_id: System.get_env(\"SMARTY_AUTH_ID\") || \"test_auth_id\",\n  auth_token: System.get_env(\"SMARTY_AUTH_TOKEN\") || \"test_auth_token\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Continuous Integration - Carrier","doc":"Carrier uses GitHub Actions for continuous integration. The CI pipeline automatically:\n\n- Runs on every push to the `main` branch and on all pull requests\n- Tests across multiple Elixir and OTP versions using a build matrix:\n  - Elixir: 1.17, 1.18\n  - OTP: 26, 27\n- Verifies that the codebase compiles successfully\n- Ensures all tests pass\n- Checks code formatting\n\nYou can see the CI configuration in `.github/workflows/ci.yml`.","ref":"readme.html#continuous-integration"},{"type":"extras","title":"Usage - Carrier","doc":"TBD","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}